@@ -1,7 +1,8 @@
 use std::env::current_dir;
 
 use clap::ArgMatches;
-use mit_commit_message_lints::{external, lints::Lints};
+use mit_commit_message_lints::{external, lints::read_from_toml_or_else_vcs};
+use mit_lint::Lints;
 
 use crate::{errors::GitMitConfigError, get_vcs};
 
@@ -18,7 +19,7 @@ fn run(matches: &ArgMatches) -> Result<(), GitMitConfigError> {
     let mut vcs = get_vcs(is_local, &current_dir)?;
     let toml = external::read_toml(current_dir)?;
 
-    let lints = Lints::read_from_toml_or_else_vcs(&toml, &mut vcs)?;
+    let lints = read_from_toml_or_else_vcs(&toml, &mut vcs)?;
     mit_commit_message_lints::console::style::lint_table(Lints::available(), &lints);
 
     Ok(())
