@@ -1,5 +1,5 @@
 use clap::ArgMatches;
-use mit_commit_message_lints::{external, lints::Lints};
+use mit_commit_message_lints::{external, lints::read_from_toml_or_else_vcs};
 
 use crate::{current_dir, errors::GitMitConfigError, get_vcs};
 
@@ -16,7 +16,7 @@ fn run(matches: &ArgMatches) -> Result<(), GitMitConfigError> {
     let mut vcs = get_vcs(is_local, &current_dir)?;
     let toml = external::read_toml(current_dir)?;
 
-    let lints = Lints::read_from_toml_or_else_vcs(&toml, &mut vcs)?;
+    let lints = read_from_toml_or_else_vcs(&toml, &mut vcs)?;
     mit_commit_message_lints::console::style::lint_table(&lints, &lints);
 
     Ok(())
